==> members-facade-2.4.1-20221010.093133-6-sources.jar: com/bizvane/members/facade/vo/qywx/MallShareRecordListResponseVO.java <==
package com.bizvane.members.facade.vo.qywx;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Builder;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotNull;

/**
 * @author baofeng@bizvane.cn
 * @createTime 2022-09-08 11:51:42
 * @description: 商品秀导购分享分页列表查询请求对象
 */
@ApiModel(value = "商品秀导购分享分页列表查询结果对象")
@Getter
@Setter
public class MallShareRecordListResponseVO {

    @ApiModelProperty(name = "sysCompanyId", value = "企业ID", example = "1L")
    private Long sysCompanyId;

    @ApiModelProperty(name = "sysBrandId", value = "品牌ID", example = "1L")
    private Long sysBrandId;

    @ApiModelProperty(name = "skuCode", value = "货号", example = "")
    private String skuCode;

    @ApiModelProperty(name = "productCode", value = "商品编号", example = "")
    private String productCode;

    @ApiModelProperty(name = "productName", value = "商品名称", example = "")
    private String productName;

    @ApiModelProperty(name = "goodsPictureUrl", value = "商品图片", example = "")
    private String goodsPictureUrl;

    @ApiModelProperty(name = "pageUrl", value = "页面Url", example = "")
    private String pageUrl;

    @ApiModelProperty(name = "pageName", value = "页面名称", example = "")
    private String pageName;

    @ApiModelProperty(name = "viewCount", value = "浏览量", example = "")
    private Long viewCount;

    @ApiModelProperty(name = "分享时间", value = "", example = "yyyy-MM-dd HH:mm")
    private String shareTime;


}

==> members-facade-20250718-20250722.104048-6-sources.jar: com/bizvane/members/facade/vo/qywx/MallShareRecordListResponseVO.java <==
package com.bizvane.members.facade.vo.qywx;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Builder;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotNull;

/**
 * @author baofeng@bizvane.cn
 * @createTime 2022-09-08 11:51:42
 * @description: 商品秀导购分享分页列表查询结果对象
 */
@ApiModel(value = "商品秀导购分享分页列表查询结果对象")
@Getter
@Setter
public class MallShareRecordListResponseVO {

    @ApiModelProperty(name = "sysCompanyId", value = "企业ID", example = "1L")
    private Long sysCompanyId;

    @ApiModelProperty(name = "sysBrandId", value = "品牌ID", example = "1L")
    private Long sysBrandId;

    @ApiModelProperty(name = "skuCode", value = "货号", example = "")
    private String skuCode;

    @ApiModelProperty(name = "productCode", value = "商品编号", example = "")
    private String productCode;

    @ApiModelProperty(name = "productName", value = "商品名称", example = "")
    private String productName;

    @ApiModelProperty(name = "goodsPictureUrl", value = "商品图片", example = "")
    private String goodsPictureUrl;

    @ApiModelProperty(name = "pageUrl", value = "页面Url", example = "")
    private String pageUrl;

    @ApiModelProperty(name = "pageName", value = "页面名称", example = "")
    private String pageName;

    @ApiModelProperty(name = "viewCount", value = "浏览量", example = "")
    private Long viewCount;

    @ApiModelProperty(name = "shareTime", value = "分享时间", example = "yyyy-MM-dd HH:mm")
    private String shareTime;


}
